==> r-cran-fitdistrplus_1.2-1.orig.tar.gz: fitdistrplus/R/util-mledist-vcov.R <==
#############################################################################
#   Copyright (c) 2024 Christophe Dutang, Marie Laure Delignette-Muller
#                                                                                                                                                                        
#   This program is free software; you can redistribute it and/or modify                                               
#   it under the terms of the GNU General Public License as published by                                         
#   the Free Software Foundation; either version 2 of the License, or                                                   
#   (at your option) any later version.                                                                                                            
#                                                                                                                                                                         
#   This program is distributed in the hope that it will be useful,                                                             
#   but WITHOUT ANY WARRANTY; without even the implied warranty of                                          
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 
#   GNU General Public License for more details.                                                                                    
#                                                                                                                                                                         
#   You should have received a copy of the GNU General Public License                                           
#   along with this program; if not, write to the                                                                                           
#   Free Software Foundation, Inc.,                                                                                                              
#   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA                                                             
#                                                                                                                                                                         
#############################################################################
### Theory of point estimation, Casella & Berger
###
###         R functions
### 


#compute H^{-1}
mle.vcov <- function(myhessian)
{
  if(all(!is.na(myhessian)) && qr(myhessian)$rank == NCOL(myhessian))
  {
    res <- solve(myhessian)
  }else
  {
    res <- NULL
  }
  res
}

==> r-cran-fitdistrplus_1.2-2.orig.tar.gz: fitdistrplus/R/util-mledist-vcov.R <==
#############################################################################
#   Copyright (c) 2024 Christophe Dutang, Marie Laure Delignette-Muller
#                                                                                                                                                                        
#   This program is free software; you can redistribute it and/or modify                                               
#   it under the terms of the GNU General Public License as published by                                         
#   the Free Software Foundation; either version 2 of the License, or                                                   
#   (at your option) any later version.                                                                                                            
#                                                                                                                                                                         
#   This program is distributed in the hope that it will be useful,                                                             
#   but WITHOUT ANY WARRANTY; without even the implied warranty of                                          
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 
#   GNU General Public License for more details.                                                                                    
#                                                                                                                                                                         
#   You should have received a copy of the GNU General Public License                                           
#   along with this program; if not, write to the                                                                                           
#   Free Software Foundation, Inc.,                                                                                                              
#   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA                                                             
#                                                                                                                                                                         
#############################################################################
### Theory of point estimation, Casella & Berger
###
###         R functions
### 


#compute H^{-1}/n
mle.vcov <- function(myhessian, nsample)
{
  if(all(!is.na(myhessian)) && qr(myhessian)$rank == NCOL(myhessian))
  {
    res <- solve(myhessian)/nsample
  }else
  {
    res <- NULL
  }
  res
}
